@@ -1,12 +1,14 @@
 package HTML::FormWidgets::Slider;
 
-# @(#)$Id: Slider.pm 154 2009-04-09 17:04:48Z pjf $
+# @(#)$Id: Slider.pm 184 2009-06-13 22:25:28Z pjf $
 
 use strict;
 use warnings;
 use parent qw(HTML::FormWidgets);
 
-use version; our $VERSION = qv( sprintf '0.4.%d', q$Rev: 154 $ =~ /\d+/g );
+use version; our $VERSION = qv( sprintf '0.5.%d', q$Rev: 184 $ =~ /\d+/g );
+
+my $NUL = q();
 
 __PACKAGE__->mk_accessors( qw(display element hide js_obj mode offset range
                               snap steps wheel) );
@@ -35,9 +37,11 @@ sub _render {
    my $elem = $self->element;
    my $id   = $self->name.q(_slider);
    my $size = int ((log $self->steps) / (log 10));
-   my $html = q();
+   my $html = $NUL;
    my $text;
 
+   $args->{default} ||= q(50);
+
    if ($self->display) {
       $html .= $hacc->textfield( { name     => $self->name,
                                    readonly => 1,
@@ -48,7 +52,7 @@ sub _render {
       push @{ $self->hide }, {
          content => $hacc->input( { name  => $self->name,
                                     type  => q(hidden),
-                                    value => $args->{default} || q() } ) };
+                                    value => $args->{default} } ) };
    }
 
    $text  = $hacc->div( { class => q(knob) } );
